OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ne skribeblas la dosierujo „config“!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Igi la agordodosierujon alirebla de la servilo kutime solvas tiun problemon.",
    "See %s" : "Vidi %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Aŭ, se vi preferas lasi la dosieron config.php nurlega, metu la opcion „config_is_read_only“ al vera („true“) ene de ĝi.",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Igi la agordodosierujon alirebla de la servilo kutime solvas tiun problemon. Vidu %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Aŭ, se vi preferas lasi la dosieron config.php nurlega, metu la opcion „config_is_read_only“ al vera („true“) ene de ĝi. Vidu %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "La dosieroj de la aplikaĵo %1$s ne estis bone anstataŭigitaj. Certigu, ke tiu aplikaĵa versio kongruas kun la servilo.",
    "Sample configuration detected" : "Ekzempla agordo trovita",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ekzempla agordo estis kopiita en via sistemo. Tio povas paneigi vian instalaĵon, kaj ne estas subtenata. Bv. legi la dokumentaron antaŭ ol fari ŝanĝojn en config.php",
    "%1$s and %2$s" : "%1$s kaj %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s kaj %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s kaj %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s kaj %5$s",
    "Education Edition" : "Eldono por edukado",
    "Enterprise bundle" : "Aplikaĵa kuniĝo por firmao",
    "Groupware bundle" : "Aplikaĵa kuniĝo por grupa kunlaborado",
    "Social sharing bundle" : "Aplikaĵa kuniĝo por socia kuhavigo",
    "PHP %s or higher is required." : "PHP %s aŭ pli alta necesas.",
    "PHP with a version lower than %s is required." : "Necesas pli malalta eldono de PHP ol %s.",
    "%sbit or higher PHP required." : "PHP je %sbitoj aŭ pli alta necesas.",
    "Following databases are supported: %s" : "La jenaj datumbazoj estas subtenataj: %s",
    "The command line tool %s could not be found" : "La komandlinia ilo %s ne troviĝis",
    "The library %s is not available." : "La biblioteko %s ne haveblas.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Biblioteko %1$s kun versio pli ol %2$s bezoniĝas. Nuna versio estas %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Biblioteko %1$s kun versio malpli ol %2$s bezoniĝas. Nuna versio estas %3$s.",
    "Following platforms are supported: %s" : "La jenaj platformoj estas subtenataj: %s",
    "Server version %s or higher is required." : "Servilo kun versio %s aŭ pli bezoniĝas.",
    "Server version %s or lower is required." : "Servilo kun versio %s aŭ malpli bezoniĝas.",
    "Logged in user must be an admin or sub admin" : "La ensalutanta uzanto estu administranto aŭ subadministranto",
    "Logged in user must be an admin" : "La ensalutanta uzanto estu administranto",
    "Wiping of device %s has started" : "Forviŝado de la aparato %s komencis",
    "Wiping of device »%s« has started" : "Forviŝado de la aparato „%s“ komencis",
    "»%s« started remote wipe" : "„%s“ komencis foran forviŝadon",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "La aparato aŭ aplikaĵo „%s“ komencis la taskon de fora forviŝado. Vi ricevos plian retmesaĝon, kiam la tasko finiĝos",
    "Wiping of device %s has finished" : "La forviŝado de la aparato %s finiĝis",
    "Wiping of device »%s« has finished" : "La forviŝado de la aparato „%s“ finiĝis",
    "»%s« finished remote wipe" : "„%s“ finis la foran forviŝadon",
    "Device or application »%s« has finished the remote wipe process." : "La aparato aŭ aplikaĵo „%s“ finis la taskon de fora forviŝado.",
    "Remote wipe started" : "Defora forviŝado komenciĝis",
    "A remote wipe was started on device %s" : "Defora forviŝado komenciĝis ĉe aparato %s",
    "Remote wipe finished" : "Defora forviŝado finis",
    "The remote wipe on %s has finished" : "La defora forviŝado ĉe %s finis",
    "Authentication" : "Aŭtentigo",
    "Unknown filetype" : "Nekonata dosiertipo",
    "Invalid image" : "Nevalida bildo",
    "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
    "today" : "hodiaŭ",
    "tomorrow" : "morgaŭ",
    "yesterday" : "hieraŭ",
    "_in %n day_::_in %n days_" : ["post %n tago","post %n tagoj"],
    "_%n day ago_::_%n days ago_" : ["antaŭ %n tago","antaŭ %n tagoj"],
    "next month" : "venontmonate",
    "last month" : "lastmonate",
    "_in %n month_::_in %n months_" : ["post %n monato","post %n monatoj"],
    "_%n month ago_::_%n months ago_" : ["antaŭ %n monato","antaŭ %n monatoj"],
    "next year" : "venontjare",
    "last year" : "lastjare",
    "_in %n year_::_in %n years_" : ["post %n jaro","post %n jaroj"],
    "_%n year ago_::_%n years ago_" : ["antaŭ %n jaro","antaŭ %n jaroj"],
    "_in %n hour_::_in %n hours_" : ["post %n horo","post %n horoj"],
    "_%n hour ago_::_%n hours ago_" : ["antaŭ %n horo","antaŭ %n horoj"],
    "_in %n minute_::_in %n minutes_" : ["post %n minuto","post %n minutoj"],
    "_%n minute ago_::_%n minutes ago_" : ["antaŭ %n minuto","antaŭ %n minutoj"],
    "in a few seconds" : "post kelkaj sekundoj",
    "seconds ago" : "antaŭ kelkaj sekundoj",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulo kun identigilo %s ne ekzistas. Bv. ŝalti ĝin en la aplikaĵa agordo aŭ kontakti vian administranton.",
    "File name is a reserved word" : "Dosiernomo estas rezervita vorto",
    "File name contains at least one invalid character" : "Dosiernomo enhavas almenaŭ unu nevalidan signon",
    "File name is too long" : "La dosiernomo tro longas",
    "Dot files are not allowed" : "Dosiernomo, kiu komenciĝas per punkto, ne estas permesata",
    "Empty filename is not allowed" : "Malplena dosiernomo ne estas permesata",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplikaĵo „%s“ ne instaleblas, ĉar ties dosiero „appinfo“ ne legeblis.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplikaĵo „%s“ ne instaleblas, ĉar ĝi ne kongruas kun tiu servila versio.",
    "__language_name__" : "Esperanto",
    "This is an automatically sent email, please do not reply." : "Tio estas aŭtomate sendita retpoŝtmesaĝo; bv. ne respondi.",
    "Help" : "Helpo",
    "Apps" : "Aplikaĵoj",
    "Settings" : "Agordo",
    "Log out" : "Elsaluti",
    "Users" : "Uzantoj",
    "Unknown user" : "Nekonata uzanto",
    "Overview" : "Superrigardo",
    "Basic settings" : "Bazaj agordoj",
    "Sharing" : "Kunhavigo",
    "Security" : "Sekurigo",
    "Groupware" : "Grupa kunlaborado",
    "Additional settings" : "Plia agordo",
    "Personal info" : "Persona informo",
    "Mobile & desktop" : "Porteblaj kaj labortablaj aplikaĵoj",
    "%s enter the database username and name." : "%s entajpu la nomon kaj la uzantnomon de la datumbazo.",
    "%s enter the database username." : "%s entajpu la datumbazan uzantnomon.",
    "%s enter the database name." : "%s entajpu la datumbazan nomon.",
    "%s you may not use dots in the database name" : "%s vi ne povas uzi punktojn en la nomo de la datumbazo",
    "Oracle connection could not be established" : "Konekto al Oracle ne povis stariĝi",
    "Oracle username and/or password not valid" : "La uzantnomo aŭ la pasvorto de Oracle ne validas",
    "PostgreSQL username and/or password not valid" : "La uzantnomo aŭ la pasvorto de PostgreSQL ne validas",
    "You need to enter details of an existing account." : "Vi entajpu detalojn pri ekzistanta konto.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "MacOS X ne estas subtenata kaj %s ne bone funkcios ĉe ĝi. Uzu ĝin je via risko!",
    "For the best results, please consider using a GNU/Linux server instead." : "Por pli bona funkciado, bv. pripensi uzi GNU-Linuksan servilon anstataŭe.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ŝajnas, ke tiu servilo %s uzas 32-bitan PHP-version, kaj ke la agordo „open_basedir“ ekzistas. Tio kaŭzos problemojn pri dosieroj pli grandaj ol 4 GB, kaj do estas tre malrekomendita.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bv. forigi la agordon „open_basedir“ de via php.ini, aŭ uzu 64-bitan version de PHP.",
    "Set an admin username." : "Agordi uzantnomon de administranto.",
    "Set an admin password." : "Agordi pasvorton de administranto.",
    "Can't create or write into the data directory %s" : "Ne kreeblas aŭ ne skribeblas la datumdosierujo %s",
    "Invalid Federated Cloud ID" : "Nevalida federnuba identigilo",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Kunhava interna servo %s devas realigi la interfacon „OCP\\Share_Backend“",
    "Sharing backend %s not found" : "Kunhava interna servo %s ne troviĝas",
    "Sharing backend for %s not found" : "Kunhava interna servo por %s ne troviĝas",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s kunhavigis „%2$s“ kun vi kaj volas aldoni:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s kunhavigis „%2$s“ kun vi kaj volas aldoni",
    "»%s« added a note to a file shared with you" : "„%s“ aldonis noton al dosiero kunhavigita kun vi",
    "Open »%s«" : "Malfermi „%s“",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "You are not allowed to share %s" : "Vi ne permesatas kunhavigi %s",
    "Can’t increase permissions of %s" : "Ne eblas pliigi permesojn de %s",
    "Files can’t be shared with delete permissions" : "Dosieroj ne estas kunhavigitaj kun permesoj de forigo",
    "Files can’t be shared with create permissions" : "Dosieroj ne estas kunhavigitaj kun permesoj de kreado",
    "Expiration date is in the past" : "Limdato troviĝas en la estinteco",
    "Can’t set expiration date more than %s days in the future" : "Ne eblas agordi limdaton pli ol %s tagojn en la estonteco",
    "%1$s shared »%2$s« with you" : "%1$s kunhavigis „%2$s“ kun vi",
    "%1$s shared »%2$s« with you." : "%1$s kunhavigis „%2$s“ kun vi.",
    "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
    "The requested share does not exist anymore" : "La petita kunhavo ne plu ekzistas",
    "Could not find category \"%s\"" : "Ne troviĝis kategorio „%s“",
    "Sunday" : "dimanĉo",
    "Monday" : "lundo",
    "Tuesday" : "mardo",
    "Wednesday" : "merkredo",
    "Thursday" : "ĵaŭdo",
    "Friday" : "vendredo",
    "Saturday" : "sabato",
    "Sun." : "dim.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mer.",
    "Thu." : "ĵaŭ.",
    "Fri." : "ven.",
    "Sat." : "sab.",
    "Su" : "Di",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Ĵa",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "Januaro",
    "February" : "Februaro",
    "March" : "Marto",
    "April" : "Aprilo",
    "May" : "Majo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Aŭgusto",
    "September" : "Septembro",
    "October" : "Oktobro",
    "November" : "Novembro",
    "December" : "Decembro",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aŭg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Nur la jenaj signoj eblas en uzantnomo: „a“ ĝis „z“, „A“ ĝis „Z“, „0“ ĝis „9“ kaj „_“ (substreko), „@“, „-“ (streketo), „'“ (apostrofo) kaj „.“ (punkto)",
    "A valid username must be provided" : "Valida uzantnomo devas esti provizita",
    "Username contains whitespace at the beginning or at the end" : "Uzantnomo enhavas spaceton ĉe la komenco aŭ la fino",
    "Username must not consist of dots only" : "Uzantnomo ne povas enhavi nur punktojn",
    "A valid password must be provided" : "Valida pasvorto devas esti provizita",
    "The username is already being used" : "La uzantnomo jam uziĝas",
    "Could not create user" : "Ne povis krei uzanton",
    "User disabled" : "Uzanto malebligita",
    "Login canceled by app" : "Ensaluto estis nuligita de aplikaĵo",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "La aplikaĵo „%1$s“ ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas: %2$s",
    "a safe home for all your data" : "sekura hejmo por ĉiuj viaj datumoj",
    "File is currently busy, please try again later" : "La dosiero estas nun okupita, bv. reprovi poste",
    "Can't read file" : "Ne legeblas dosiero",
    "Application is not enabled" : "La aplikaĵo ne estas ŝaltita",
    "Authentication error" : "Aŭtentiga eraro",
    "Token expired. Please reload page." : "Ĵetono eksvalidiĝis. Bonvolu reŝargi la paĝon.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Neniu datumbaza pelilo (sqlite, mysql, or postgresql) instalita.",
    "Cannot write into \"config\" directory" : "Ne skribeblas la dosierujo „config“",
    "Cannot write into \"apps\" directory" : "Ne skribeblas la dosierujo „apps“",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Igi la „apps“ dosierujon alirebla de la servilo aŭ malŝalti la aplikaĵejon en la agordodosiero kutime solvas tiun problemon. Vidu %s",
    "Cannot create \"data\" directory" : "Ne kreeblas la dosierujo „data“",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Igi la radikan dosierujon alirebla de la servilo kutime solvas tiun problemon. Vidu %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Igi la radikan dosierujon skribebla de la servilo kutime solvas tiun problemon. Vidu %s.",
    "Setting locale to %s failed" : "Agordi la lokaĵaron al %s malsukcesis",
    "Please install one of these locales on your system and restart your webserver." : "Bv. instali unu el tiu lokaĵaro ĉe via sistemo, kaj restartigu la TTT-servilon.",
    "Please ask your server administrator to install the module." : "Bonvolu peti vian sistemadministranton instali la modulon.",
    "PHP module %s not installed." : "PHP-modulo %s ne instalita.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-agordo „%s“ ne egalas al „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Modifo de tiu agordo en „php.ini“ funkciigas Nextcloud-on denove.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload egalas al „%s“ anstataŭ al la atendata „0“",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Por ripari tiun problemon, agordu <code>mbstring.func_overload</code> al <code>0</code> en via dosiero „php.ini“",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 almenaŭ necesas. Nun %s estas instalita.",
    "To fix this issue update your libxml2 version and restart your web server." : "Por ripari tiun problemon, ĝisdatigu vian version de libxml2, kaj restartigu la TTT-servilon.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ŝajne estas agordita por senigi la entekstajn dokumentarojn. Tio malfunkciigos plurajn kernajn aplikaĵojn.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tion kaŭzas probable kaŝilo aŭ plirapidigilo kiel „Zend OPcache“ aŭ „eAccelerator“.",
    "PHP modules have been installed, but they are still listed as missing?" : "Ĉu PHP-moduloj estas instalitaj, sed ĉiam montritaj kiel mankantaj?",
    "Please ask your server administrator to restart the web server." : "Bonvolu peti vian serviladministranton, ke ŝi aŭ li restartigu la TTT-servilon.",
    "PostgreSQL >= 9 required" : "PostgreSQL ⩾ 9 necesas",
    "Please upgrade your database version" : "Bonvolu ĝisdatigi la version de via datumbazo",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bv. ŝanĝi la permesojn al 0770, tiel la dosierujo ne listigeblas de aliaj uzantoj.",
    "Your data directory is readable by other users" : "Via dosierujo de datumoj legeblas de aliaj uzantoj",
    "Your data directory must be an absolute path" : "Via dosierujo de datumoj estu absoluta vojo",
    "Check the value of \"datadirectory\" in your configuration" : "Kontrolu la valoron de „datadirectory“ en via agordo",
    "Your data directory is invalid" : "Via dosierujo de datumoj ne validas",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Certigu, ke estas dosiero nomata „.ocdata“ en la radiko de la dosierujo de datumoj.",
    "Action \"%s\" not supported or implemented." : "Ago „%s“ ne estas subtenata aŭ realigita.",
    "Authentication failed, wrong token or provider ID given" : "Aŭtentigo malsukcesis: neĝusta ĵetono aŭ provizanto-identigilo specifita",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametroj mankas por realigi la peton. Mankantaj parametroj: „%s“",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Identigilo „%1$s“ jam uziĝas de federnuba provizanto „%2$s“",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Federnuba provizanto kun identigilo „%s“ ne ekzistas.",
    "Could not obtain lock type %d on \"%s\"." : "Ne eblis havi ŝlostipon %d sur „%s“.",
    "Storage unauthorized. %s" : "Konservejo ne permesata. %s",
    "Storage incomplete configuration. %s" : "Nekompleta agordo de konservejo. %s",
    "Storage connection error. %s" : "Konekta eraro al konservejo. %s",
    "Storage is temporarily not available" : "Konservejo provizore ne disponeblas",
    "Storage connection timeout. %s" : "Konekto al konservejo eltempiĝis. %s",
    "Create" : "Krei",
    "Change" : "Ŝanĝi",
    "Delete" : "Forigi",
    "Share" : "Kunhavigi",
    "Unlimited" : "Senlima",
    "Verifying" : "Kontrolado",
    "Verifying …" : "Kontrolado...",
    "Verify" : "Kontroli",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Kunhavigo de %s malsukcesis, ĉar la interna servo ne permesas kunhavon de tipo %i",
    "Sharing %s failed, because the file does not exist" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne ekzistas",
    "Sharing %s failed, because you can not share with yourself" : "Kunhavigo de %s malsukcesis, ĉar vi ne povas kunhavigi kun vi mem",
    "Sharing %1$s failed, because the user %2$s does not exist" : "Kunhavigo de %1$s malsukcesis, ĉar la uzanto %2$s ne ekzistas",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Kunhavigo de %1$s malsukcesis, ĉar la uzanto %2$s estas ano de neniu grupo, de kiu %3$s estas ano",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar tiu elemento jam kunhaviĝas kun %2$s",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar la ero jam kunhaviĝis kun uzanto %2$s",
    "Sharing %1$s failed, because the group %2$s does not exist" : "Kunhavigo de %1$s malsukcesis, ĉar la grupo %2$s ne ekzistas",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Kunhavigo de %1$s malsukcesis, ĉar %2$s ne estas ano de la grupo %3$s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Vi bezonas doni pasvorton por krei publikan ligilon, ĉar nur protektitaj ligiloj estas permesataj",
    "Sharing %s failed, because sharing with links is not allowed" : "Kunhavo de %s malsukcesis, ĉar kunhavo per ligiloj ne permesatas",
    "Not allowed to create a federated share with the same user" : "Vi ne permesas krei federan kunhavon kun la sama uzanto",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Kunhavigo de %1$s malsukcesis, ne eblis trovi %2$s; eble la servilo estas provizore neatingebla.",
    "Share type %1$s is not valid for %2$s" : "Kunhava tipo %1$s ne validas por %2$s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ne eblis agordi limdaton. Kunhavoj ne povas senvalidiĝi pli ol %s post sia kreado.",
    "Cannot set expiration date. Expiration date is in the past" : "Ne eblis agordi limdaton: ĝi troviĝas en la estinteco.",
    "Sharing failed, because the user %s is the original sharer" : "Kunhavigo malsukcesis, ĉar la uzanto %s estas la origina kunhavanto",
    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar la permesoj transpasas tiujn de %2$s",
    "Sharing %s failed, because resharing is not allowed" : "Kunhavigo de %s malsukcesis, ĉar rekunhavigo ne permesatas",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Kunhavigo de %1$s malsukcesis, ĉar la kunhava interna servo por %2$s ne povis trovi ĝian fonton",
    "Sharing %s failed, because the file could not be found in the file cache" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne troveblis en la dosiera kaŝmemoro"
},
"nplurals=2; plural=(n != 1);");
